Extension UI Overview
This page contains annotated diagrams of the browser extension User Interface.
Screenshot of Main View
1
2
3
4
5
6
7
8
9
10
11
12
13
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
- Run config
- Save config to browser storage
- Load config to from a file
- Save config to a file.
- Add selector group. Useful for extracting different data from same page.
- Menu with more actions
- Status indicator. Statuses are defined in `src/types.ts`
- Show logs.
- Selector definition tab
- Scrape configuration tab.
- Browser storage library tab.
- Collapse selector group.
- Rename selector group.
- Delete selector group.
- Selector (CSS or XPath) for element containing individual items (optional).
- Start interactive element picker.
- Field name input
- Delete field.
- Field selector input (CSS or XPath).
- Treat selector as list for this field.
- Results section.
- Show results as JSON.
- Download extracted data.
- Copy extracted data to clipboard.
- Show results in a new tab.
- Clear extracted results.
- Collapse results for a selector group.
Screenshot of Config Tab view
1
2
3
4
- Pagination section. See `src/types:PaginationConfig` for definition.
- Extraction options section. See `src/types:ExtractionOptions` for definition.
- Metadata section. See `src/types:Metadata` for definition.
- Variables section. Not implemented
Next pagination config
1
2
3
- Selector (CSS or XPath) for next button.
- Maximum number of pages to navigate. Zero means unlimited
- Test navigation by moving to the next page.
Links pagination config
1
2
- Input for links to navigate to. One per line.
- Test navigation by moving to the next page.
Template pagination config
1
2
3
4
5
- Input for URL template. The template is used to create the URL for the next page.
- Start page number.
- Number to add to previous to get next page
- Maximum number of pages to scrape. Zero means unlimited
- Test navigation by going to next page using defined values.
Screenshot of Config Library
1
2
3
4
5
6
- Type to search in id or url fields of configs
- Change config sort
- Rename saved configuration.
- Delete saved configuration.
- Show configuration definition.
- Load configuration into sidebar
Screenshot of Results New Tab
1
2
3
4
5
- View Results
- View Logs.
- View results as JSON
- Download results data in different formats.
- Copy results data in different formats.